pub enum Decision {
Allow,
AskUser,
Deny,
AllowOnce,
AllowSession,
AllowAlways,
}Variants
Allow
AskUser
Deny
AllowOnce
Allow this specific tool call once and ask again next time.
AllowSession
Allow this tool for the remainder of the session.
AllowAlways
Allow this tool permanently (persisted to disk).